@@ -2,6 +2,8 @@ package org.jmx4perl.converter;
 
 import java.lang.reflect.Array;
 
+import org.json.simple.JSONArray;
+import org.json.simple.JSONObject;
 import org.testng.Assert;
 import org.testng.annotations.BeforeTest;
 import org.testng.annotations.Test;
@@ -87,6 +89,22 @@ public class StringToObjectConverterTest {
         assertEquals("String conversion","10",obj);
     }
 
+    @Test
+    public void jsonConversion() {
+        JSONObject json = new JSONObject();
+        json.put("name","roland");
+        json.put("kind","jolokia");
+
+        Object object = converter.convertFromString(JSONObject.class.getName(),json.toString());
+        assertEquals(json,object);
+
+        JSONArray array = new JSONArray();
+        array.add("roland");
+        array.add("jolokia");
+
+        object = converter.convertFromString(JSONArray.class.getName(),array.toString());
+        assertEquals(array,object);
+    }
     @Test
     public void arrayConversions() {
         Object obj = converter.convertFromString(new int[0].getClass().getName(),"10,20,30");
