@@ -47,6 +47,10 @@ List all MBeans available
 
 Search for MBeans
 
+=ite AGENT_VERSION 
+
+Get the agent's version and extra runtime information of the serverside.
+
 =item REGISTER_NOTIFICATION
 
 Register for a JMX notification (not supported yet)
@@ -305,7 +309,7 @@ sub method {
     my $self = shift;
     my $value = shift;
     if (defined($value)) {
-        die "Unknown request method ",$value if length($value) && $value !~ /^(POST|GET)$/i;
+        die "Unknown request method ",$value if length($value) && uc($value) !~ /^(POST|GET)$/i;
         $self->{method} = uc($value);
     }
     return defined($self->{method}) ? $self->{method} : undef;
